@@ -95,7 +95,7 @@ class line(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
+                 font_typeface=None, font_family='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axis
                  fig=None, ax=None, figsize=(5, 4), shape_and_position=111, azim=-138, elev=19, remove_axis=None,
                  # Setup
@@ -233,7 +233,7 @@ class scatter(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
+                 font_typeface=None, font_family='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axis
                  fig=None, ax=None, figsize=(5, 4), shape_and_position=111, azim=-138, elev=19, remove_axis=None,
                  # Setup
@@ -384,7 +384,7 @@ class surface(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
+                 font_typeface=None, font_family='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axis
                  fig=None, ax=None, figsize=(5, 4), shape_and_position=111, azim=-138, elev=19, remove_axis=None,
                  # Setup
