@@ -97,7 +97,7 @@ class line(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
+                 font_typeface=None, font_family='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
                  fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
                  scale=None, aspect=1,
@@ -248,7 +248,7 @@ class scatter(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
+                 font_typeface=None, font_family='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
                  fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
                  scale=None, aspect=1,
@@ -381,7 +381,7 @@ class heatmap(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
+                 font_typeface=None, font_family='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
                  fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
                  scale=None, aspect=1,
@@ -519,7 +519,7 @@ class quiver(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
+                 font_typeface=None, font_family='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
                  fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
                  scale=None, aspect=1,
@@ -687,7 +687,7 @@ class streamline(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
+                 font_typeface=None, font_family='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
                  fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
                  scale=None, aspect=1,
@@ -840,7 +840,7 @@ class fill_area(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
+                 font_typeface=None, font_family='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
                  fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
                  scale=None, aspect=1,
